@@ -4,6 +4,7 @@ These are the functions available when importing __archimedes__.
 
 from archimedes.auth import NoneAuth, get_auth
 from archimedes.configuration import ArchimedesConstants  # config
+from archimedes.data.api import rk_within_day
 from archimedes.data.api.forecast import (
     forecast_diff,
     forecast_get,
@@ -26,12 +27,16 @@ from archimedes.data.api.prediction import (
     store_predictions,
 )
 from archimedes.data.api.rk_within_day import (
-    rk_comparison_by_price,
-    rk_within_day_directions,
-    rk_within_day_distributions,
-    rk_within_day_large_down_fps,
-    rk_within_day_large_up_fps,
+    comparison_by_price as rk_comparison_by_price,
 )
+from archimedes.data.api.rk_within_day import directions as rk_within_day_directions
+from archimedes.data.api.rk_within_day import (
+    distributions as rk_within_day_distributions,
+)
+from archimedes.data.api.rk_within_day import (
+    large_down_fps as rk_within_day_large_down_fps,
+)
+from archimedes.data.api.rk_within_day import large_up_fps as rk_within_day_large_up_fps
 from archimedes.data.api.umm import (
     umm_get,
     umm_get_area_codes,
@@ -40,8 +45,10 @@ from archimedes.data.api.umm import (
     umm_get_summary,
 )
 from archimedes.utils import compact_print, environ, full_print
+from archimedes.version import __version__
 
 __all__ = [
+    "__version__",
     "ArchimedesConstants",
     "get_auth",
     "NoneAuth",
@@ -68,6 +75,7 @@ __all__ = [
     "rk_within_day_large_down_fps",
     "rk_within_day_distributions",
     "rk_comparison_by_price",
+    "rk_within_day",
     "umm_get_series_list",
     "umm_get_area_codes",
     "umm_get_summary",
