@@ -1,3 +1,7 @@
+"""
+Get predictions from the Archimedes API
+"""
+
 import json
 from datetime import datetime
 from typing import Dict, List, Union
@@ -8,7 +12,7 @@ from requests.exceptions import HTTPError
 from archimedes.data.common import get_api_base_url_v2
 from archimedes.data.types import PredictionData
 from archimedes.utils.api_request import api
-from archimedes.utils.date import datetime_to_iso_format
+from archimedes.utils.date import convert_to_iso_format
 from archimedes.utils.idempotency import generate_idempotency_key
 from archimedes.utils.threaded_executor import execute_many
 
@@ -16,6 +20,7 @@ from archimedes.utils.threaded_executor import execute_many
 def get_predictions(  # pylint:disable=too-many-arguments,too-many-locals
     series_ids: List[str] = None,
     price_areas: List[str] = None,
+    filter_by: List[str] = None,
     start: Union[str, pd.Timestamp, datetime, None] = None,
     end: Union[str, pd.Timestamp, datetime, None] = None,
     ref_dt_start: Union[str, pd.Timestamp, datetime, None] = None,
@@ -42,6 +47,10 @@ def get_predictions(  # pylint:disable=too-many-arguments,too-many-locals
     Args:
         series_ids (List[str], optional): The series ids to get.
         price_areas (List[str], optional): The price areas to get the data for.
+        filter_by (List[str], optional):
+            Additional filtering of the json_data field.  The fields available
+            will vary depending on the series_id being fetched.  Examples:
+                'variant=COND', 'direction=UP', 'hours_ahead>=5'
         start (str, pd.Timestamp, optional):
             The first datetime to fetch (inclusive). Returns all if None.
             Defaults to None.
@@ -63,10 +72,13 @@ def get_predictions(  # pylint:disable=too-many-arguments,too-many-locals
     if isinstance(price_areas, str):
         price_areas = [price_areas]
 
-    start = datetime_to_iso_format(start)
-    end = datetime_to_iso_format(end)
-    ref_dt_start = datetime_to_iso_format(ref_dt_start)
-    ref_dt_end = datetime_to_iso_format(ref_dt_end)
+    if isinstance(filter_by, str):
+        filter_by = [filter_by]
+
+    start = convert_to_iso_format(start)
+    end = convert_to_iso_format(end)
+    ref_dt_start = convert_to_iso_format(ref_dt_start)
+    ref_dt_end = convert_to_iso_format(ref_dt_end)
 
     query = {}
 
@@ -82,6 +94,9 @@ def get_predictions(  # pylint:disable=too-many-arguments,too-many-locals
     if ref_dt_end is not None:
         query["ref_dt_end"] = pd.to_datetime(ref_dt_end, utc=True)
 
+    if filter_by is not None:
+        query["filter_by"] = filter_by
+
     queries = [query]
     if series_ids is not None:
         queries = [
@@ -102,12 +117,12 @@ def get_predictions(  # pylint:disable=too-many-arguments,too-many-locals
         return aggr
 
     params_array = [
-        dict(
-            url=f"{get_api_base_url_v2()}/data/get_predictions",
-            access_token=access_token,
-            params=query,
+        {
+            "url": f"{get_api_base_url_v2()}/data/get_predictions",
+            "access_token": access_token,
+            "params": query,
             **kwargs,
-        )
+        }
         for query in queries
     ]
 
@@ -240,9 +255,9 @@ def store_prediction(
     """
     payload = {
         "prediction_id": prediction_id,
-        "from_dt": datetime_to_iso_format(from_dt),
-        "ref_dt": datetime_to_iso_format(ref_dt),
-        "run_dt": datetime_to_iso_format(run_dt),
+        "from_dt": convert_to_iso_format(from_dt),
+        "ref_dt": convert_to_iso_format(ref_dt),
+        "run_dt": convert_to_iso_format(run_dt),
         "data": data,
     }
 
@@ -302,9 +317,9 @@ def store_predictions(
 
     predictions = [
         {
-            "from_dt": datetime_to_iso_format(p["from_dt"]),
-            "ref_dt": datetime_to_iso_format(p["ref_dt"]),
-            "run_dt": datetime_to_iso_format(p["run_dt"]),
+            "from_dt": convert_to_iso_format(p["from_dt"]),
+            "ref_dt": convert_to_iso_format(p["ref_dt"]),
+            "run_dt": convert_to_iso_format(p["run_dt"]),
             "data": p["data"],
         }
         for p in prediction_data
